@@ -21,8 +21,7 @@
 
 LV2_SYMBOL_EXPORT
 const LV2_Lib_Descriptor*
-lv2_lib_descriptor(const char*              bundle_path,
-                   const LV2_Feature*const* features)
+lv2_lib_descriptor(const char* bundle_path, const LV2_Feature* const* features)
 {
-	return NULL;
+  return NULL;
 }
