@@ -1,6 +1,6 @@
 /*
   Lilv Test Plugin - Missing descriptor
-  Copyright 2011-2015 David Robillard <d@drobilla.net>
+  Copyright 2011-2018 David Robillard <d@drobilla.net>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -15,7 +15,10 @@
   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
 
-#include "lv2/lv2plug.in/ns/lv2core/lv2.h"
+#include "lv2/core/lv2.h"
+
+LV2_SYMBOL_EXPORT
+extern const char* msg;
 
 LV2_SYMBOL_EXPORT
 const char* msg = "this is not the thing you're looking for";
