@@ -1,5 +1,5 @@
 /*
-  Copyright 2007-2020 David Robillard <http://drobilla.net>
+  Copyright 2007-2020 David Robillard <d@drobilla.net>
 
   Permission to use, copy, modify, and/or distribute this software for any
   purpose with or without fee is hereby granted, provided that the above
@@ -27,22 +27,21 @@ static const char* const plugin_ttl = ":plug a lv2:Plugin .\n";
 int
 main(void)
 {
-	LilvTestEnv* const env   = lilv_test_env_new();
-	LilvWorld* const   world = env->world;
+  LilvTestEnv* const env   = lilv_test_env_new();
+  LilvWorld* const   world = env->world;
 
-	if (start_bundle(env, SIMPLE_MANIFEST_TTL, plugin_ttl)) {
-		return 1;
-	}
+  if (start_bundle(env, SIMPLE_MANIFEST_TTL, plugin_ttl)) {
+    return 1;
+  }
 
-	const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
-	const LilvPlugin*  explug =
-	    lilv_plugins_get_by_uri(plugins, env->plugin1_uri);
+  const LilvPlugins* plugins = lilv_world_get_all_plugins(world);
+  const LilvPlugin* explug = lilv_plugins_get_by_uri(plugins, env->plugin1_uri);
 
-	assert(explug);
-	assert(!lilv_plugin_verify(explug));
+  assert(explug);
+  assert(!lilv_plugin_verify(explug));
 
-	delete_bundle(env);
-	lilv_test_env_free(env);
+  delete_bundle(env);
+  lilv_test_env_free(env);
 
-	return 0;
+  return 0;
 }
